# mypy-boto3-ecs

[![PyPI - mypy-boto3-ecs](https://img.shields.io/pypi/v/mypy-boto3-ecs.svg?color=blue)](https://pypi.org/project/mypy-boto3-ecs)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-ecs.svg?color=blue)](https://pypi.org/project/mypy-boto3-ecs)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

Type annotations for
[boto3.ECS 1.14.45](https://boto3.amazonaws.com/v1/documentation/api/1.14.45/reference/services/ecs.html#ECS) service
compatible with [mypy](https://github.com/python/mypy), [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/) and other tools.

Generated by [mypy-boto3-buider 2.2.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

## How to install

Make sure you have [mypy](https://github.com/python/mypy) installed and activated in your IDE.

Install `boto3-stubs` for `ECS` service.

```bash
python -m pip install boto3-stubs[ecs]
```

## How to use

### Client annotations

`ECSClient` provides annotations for `boto3.client("ecs")`.

```python
import boto3

from mypy_boto3_ecs import ECSClient
from mypy_boto3_ecs.paginator import (
    ListAccountSettingsPaginator,
    ListAttributesPaginator,
    ListClustersPaginator,
    ListContainerInstancesPaginator,
    ListServicesPaginator,
    ListTaskDefinitionFamiliesPaginator,
    ListTaskDefinitionsPaginator,
    ListTasksPaginator,
)
from mypy_boto3_ecs.type_defs import AttachmentTypeDef, ...
from mypy_boto3_ecs.waiter import (
    ServicesInactiveWaiter,
    ServicesStableWaiter,
    TasksRunningWaiter,
    TasksStoppedWaiter,
)

client: ECSClient = boto3.client("ecs")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: ECSClient = session.client("ecs")
```

### Paginators annotations

`mypy_boto3_ecs.paginator` module contains type annotations for all paginators.

```python

client: ECSClient = boto3.client("ecs")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_account_settings_paginator: ListAccountSettingsPaginator = client.get_paginator("list_account_settings")
list_attributes_paginator: ListAttributesPaginator = client.get_paginator("list_attributes")
list_clusters_paginator: ListClustersPaginator = client.get_paginator("list_clusters")
list_container_instances_paginator: ListContainerInstancesPaginator = client.get_paginator("list_container_instances")
list_services_paginator: ListServicesPaginator = client.get_paginator("list_services")
list_task_definition_families_paginator: ListTaskDefinitionFamiliesPaginator = client.get_paginator("list_task_definition_families")
list_task_definitions_paginator: ListTaskDefinitionsPaginator = client.get_paginator("list_task_definitions")
list_tasks_paginator: ListTasksPaginator = client.get_paginator("list_tasks")
```


### Waiters annotations

`mypy_boto3_ecs.waiter` module contains type annotations for all waiters.

```python

client: ECSClient = boto3.client("ecs")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
services_inactive_waiter: ServicesInactiveWaiter = client.get_waiter("services_inactive")
services_stable_waiter: ServicesStableWaiter = client.get_waiter("services_stable")
tasks_running_waiter: TasksRunningWaiter = client.get_waiter("tasks_running")
tasks_stopped_waiter: TasksStoppedWaiter = client.get_waiter("tasks_stopped")
```





### Typed dictionations

`mypy_boto3_ecs.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python

def get_structure() -> AttachmentTypeDef:
    return {
      ...
    }
```


## Dynamic type annotations

`mypy_boto3` command generates `boto3.client/resource` type annotations for
`mypy_boto3_ecs` and other installed services.

```bash
# Run this command after you add or remove service packages
python -m mypy_boto3
```

Generated type annotations provide overloads for `boto3.client` and `boto3.resource`,
`boto3.Session.client` and `boto3.Session.resource` functions,
so explicit type annotations are not needed.

- `mypy` supports function overloads as expected
- `PyCharm` also supports function overloads, but consumes a lot of RAM, use carefully if you have many services installed
- `VSCode` does not currently support function overloads, use explicit type annotations

```python

# Type is discovered correctly by mypy and PyCharm
# VSCode still needs explicit type annotations
client = boto3.client("ecs")

session_client = boto3.Session().client("ecs")
```
